@@ -10,7 +10,8 @@ from chzzk.unofficial.models.chat import (
     DonationMessage,
     TemporaryRestrict,
 )
-from chzzk.unofficial.models.live import LiveDetail, LiveStatus
+from chzzk.unofficial.models.live import LiveDetail, LiveStatus, LiveStatusPolling
+from chzzk.unofficial.models.reconnect import ReconnectEvent, ReconnectReason, StatusChangeEvent
 from chzzk.unofficial.models.user import UserStatus
 
 __all__ = [
@@ -23,6 +24,10 @@ __all__ = [
     "DonationMessage",
     "LiveDetail",
     "LiveStatus",
+    "LiveStatusPolling",
+    "ReconnectEvent",
+    "ReconnectReason",
+    "StatusChangeEvent",
     "TemporaryRestrict",
     "UserStatus",
 ]
